@@ -30,8 +30,10 @@ class SensorImpactFDD:
         value is the directory where the current Python script is located.
         """
         if not os.path.exists("config.json"):
+            print('First time run in this path, downloading the configuration file (config.json) from the server...')
             gdown.download("https://drive.google.com/file/d/1gteh_rkjhJ7emHs-ISk-2_IGQQRDculu/view?usp=sharing",
                f'config.json', quiet=False, fuzzy=True)
+            print('config.json file is downloaded and added to the working path.')
 
         with open("config.json", "r") as jsonfile:
             self.config = json.load(jsonfile)
